import React, { useRef, useEffect } from 'react';

export const LogicInput = (props: { value: string; type: string; onChange(value: string): void; onEnter(): void; onBlur(): void }) => {
  const ref = useRef<HTMLInputElement>(null);

  useEffect(() => {
    setTimeout(() => {
      // need a timeout to make sure the input is rendered and no other interruption happens before focusing
      if (ref?.current) {
        ref.current.focus();
      }
    }, 100);
  }, []);

  return (
    <input
      ref={ref}
      className="px-1 m-0 mx-1 p-0 h-5 w-full rounded-sm border-[1px]"
      placeholder="empty"
      value={props.value}
      onMouseDownCapture={(e) => {
        e.stopPropagation();
      }}
      onChange={(e) => {
        props.onChange(e.target.value);
      }}
      onKeyDown={(e) => {
        if (e.key === 'Enter') props.onEnter();
      }}
      onBlur={(e) => props.onBlur()}
    />
  );
};
